# vim: tabstop=4 shiftwidth=4 softtabstop=4

# Copyright 2010 United States Government as represented by the
# Administrator of the National Aeronautics and Space Administration.
# All Rights Reserved.
# Copyright (c) 2013 Canonical Ltd
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.


from nova.openstack.common.gettextutils import _  # noqa
from nova.openstack.common import log as logging
from nova import utils

LOG = logging.getLogger(__name__)


def write_to_file(path, contents):
    utils.execute('tee', path,
            process_input=contents, run_as_root=True)


class VMUtils(object):
    def __init__(self):
        pass

    def container_exists(self, instance):
        (state, out) = utils.execute('lxc-info', '--name', instance['uuid'],
                   '-s', run_as_root=True)
        state = state.split()[1]
        if state == 'RUNNING':
            return True
        else:
            return False

    def stop_container(self, instance):
        utils.execute('lxc-stop', '-n', instance['uuid'], run_as_root=True)

    def start_container(self, instance):
        utils.execute('lxc-start', '-d', '--name', instance['uuid'],
            run_as_root=True)

    def destroy_container(self, instance):
        utils.execute('lxc-destroy', '-f', '-n', instance['uuid'],
            run_as_root=True)

    def find_container_pid(self, instance):
        (pid, err) = utils.execute('lxc-info', '-n', instance['uuid'], '-p',
            run_as_root=True)
        pid = pid.split()[1]
        return pid

    def list_containers(self):
        utils.execute('lxc-ls', '-1', run_as_root=True)
